
# # # # # # # # # #
#
# MODULE SCREEN 1
#
# # # # # # # # # #

proc ::VMDlite::lesson::module1 { } {
# water box simulation

    set ::VMDlite::lesson::currentFrame 1
    eval ::VMDlite::lesson::init
	# total number of frames in module
	set ::VMDlite::lesson::totalFrames 7
    eval ::VMDlite::lesson::refresh
    wm title ${::VMDlite::lesson::w} "VMDlite -- Phospholipids 1"

	set text "Welcome to the Phospholipids module! On the display you will find a cube of water.\n\nYou may slide the scale\
	below to move the simulation in time or press the \"Play\" button. You may also click within the display window and move your mouse to\
	rotate the system. Scrolling the mouse wheel will zoom in and out.\n\nWe have highlighted one water molecule\
	in pink and written its coordinates. Click \"Previous frame\" or \"Next frame\" to move a single frame forward or backward\
	in the simulation."

	# add text for current frame
	eval [list ::VMDlite::lesson::textBox ${text}]

    mol new ${::VMDlite::lesson::directory}/waterBox/waterBox.psf
    mol addfile ${::VMDlite::lesson::directory}/waterBox/waterBox.dcd waitfor all
    animate goto 0
    mol modstyle 0 [molinfo top] VDW 0.4 30
    mol modcolor 0 [molinfo top] ColorID 10
    
    mol addrep [molinfo top]
    mol modselect 1 [molinfo top] "index 2161"
    mol modstyle 1 [molinfo top] VDW 1.0 30
    mol modcolor 1 [molinfo top] ColorID 9

    set sel [atomselect top "index 2161"]
    set ::VMDlite::lesson::coordinates [measure center ${sel}]

    # frame for time scale in DCD
    ttk::frame ${::VMDlite::lesson::w}.scale \
        -relief sunken
    # actual scale
    ttk::scale ${::VMDlite::lesson::w}.scale.bar \
        -variable ::VMDlite::lesson::sliderPos \
        -from 0 -to 23 \
        -command ::VMDlite::lesson::setTime
    # buttons for manually moving through DCD
    ttk::button ${::VMDlite::lesson::w}.scale.play \
        -text "Play" \
        -command [list ::VMDlite::lesson::DCD 1]
    ttk::button ${::VMDlite::lesson::w}.scale.stop \
        -text "Stop" \
        -command [list ::VMDlite::lesson::DCD 0]
    ttk::button ${::VMDlite::lesson::w}.scale.stepBack \
        -text "Previous frame" \
        -command [list ::VMDlite::lesson::step prev]
    ttk::button ${::VMDlite::lesson::w}.scale.stepForward \
        -text "Next frame" \
        -command [list ::VMDlite::lesson::step next]

    # frame for finding velocities
#    ttk::frame ${::VMDlite::lesson::w}.velocity \
#        -relief sunken
#    ttk::label ${::VMDlite::lesson::w}.velocity.label \
#        -text "Coordinates:"
#    ttk::label ${::VMDlite::lesson::w}.velocity.coordinates \
#        -text "[format %.2f [lindex ${::VMDlite::lesson::coordinates} 0]] [format %.2f [lindex ${::VMDlite::lesson::coordinates} 1]] [format %.2f [lindex ${::VMDlite::lesson::coordinates} 2]]"
        
    # horizontal line for separation of scrollbar from buttons
    ttk::separator ${::VMDlite::lesson::w}.separator2 \
     	-orient horizontal

    pack ${::VMDlite::lesson::w}.scale \
        -before ${::VMDlite::lesson::w}.buttons \
        -fill x \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2
    pack ${::VMDlite::lesson::w}.scale.bar \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -fill x
    pack ${::VMDlite::lesson::w}.scale.stepBack \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    pack ${::VMDlite::lesson::w}.scale.play \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    pack ${::VMDlite::lesson::w}.scale.stop \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    pack ${::VMDlite::lesson::w}.scale.stepForward \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -side left
    
#    pack ${::VMDlite::lesson::w}.velocity
#    pack ${::VMDlite::lesson::w}.velocity.label -side left
#    pack ${::VMDlite::lesson::w}.velocity.coordinates -side right
    
    pack ${::VMDlite::lesson::w}.separator2 \
        -fill x \
        -pady 10

}

# # # # # # # # # #
#
# MODULE SCREEN 2
#
# # # # # # # # # #

proc ::VMDlite::lesson::module2 { } {
# show single bilayer with representations {lines, VDW, and licorice}
# discuss periodic boundary conditions and create buttons for their
# creation / annihilation.

    mol delete all
    set ::VMDlite::lesson::currentFrame 2
    eval ::VMDlite::lesson::refresh
    wm title ${::VMDlite::lesson::w} "VMDlite -- Phospholipids 2"

    mol new ${::VMDlite::lesson::directory}/membrane/membrane.pdb
    mol addfile ${::VMDlite::lesson::directory}/membrane/membrane.psf

    rotate x by -90
    rotate y by 90

    mol addrep [molinfo top]
    mol addrep [molinfo top]

    mol modstyle 0 [molinfo top] Lines 1.0
    mol modstyle 1 [molinfo top] Licorice 0.5 30 30
    mol modstyle 2 [molinfo top] VDW 1.0 30

    mol showrep [molinfo top] 1 off
    mol showrep [molinfo top] 2 off
    molinfo top set b 95

    mol showperiodic [molinfo top] 0 yY
    mol showperiodic [molinfo top] 1 yY
    mol showperiodic [molinfo top] 2 yY
    

	set text "The display now holds a phospholipid bilayer. Every cell in your body is held together by this\
		important structure.\n\nTo simulate the size of a full cell without placing more atoms in the system,\
		we use \"periodic boundary conditions\". As in Pac-Man, if an atom moves too far off screen it appears\
		on the other side. This trick allows the system to believe it is infinite. Try turning on and off\
		the periodic boundary conditions.\n\nWe also include here the ability to change representations.\
		Use the buttons to switch between lines, licorice, and VDW (van der Waals, i.e., space-filling spheres)\
		representations of the atoms.\n\n\
		Atom colors\n\
		light blue - carbon\n\
		dark blue - nitrogen\n\
		red - oxygen\n\
		brown - phosphorus\n\
		white - hydrogen\n\n\
		Click and drag anywhere within the display to view the system from different angles."

    # add text for current frame
	eval [list ::VMDlite::lesson::textBox ${text}]

# place representations buttons
::VMDlite::lesson::representationsButtons
}

# # # # # # # # # #
#
# MODULE SCREEN 3
#
# # # # # # # # # #

proc ::VMDlite::lesson::module3 { } {
# enlarge screen to show lipid then fade rest of membrane out

    graphics [molinfo top] delete all

    if {${::VMDlite::lesson::currentFrame} == 4} {
	scale by 0.25
    }

    set ::VMDlite::lesson::currentFrame 3
    eval ::VMDlite::lesson::refresh
    wm title ${::VMDlite::lesson::w} "VMDlite -- Phospholipids 3"

    mol modselect 0 [molinfo top] residue 458
    mol modselect 1 [molinfo top] residue 458
    mol modselect 2 [molinfo top] residue 458

    set sel [atomselect top "residue 458"]
    set center [measure center ${sel}]
    ${sel} delete
    molinfo top set center [list ${center}]
    scale by 4.0
    translate to 0 0 0
    display update

    # add text for current frame
    set text "Now we have zoomed into a particular phospholipid."

	# add text for current frame
	eval [list ::VMDlite::lesson::textBox ${text}]
	
	# place buttons
	::VMDlite::lesson::representationsButtons
}

# # # # # # # # # #
#
# MODULE SCREEN 4
#
# # # # # # # # # #

proc ::VMDlite::lesson::module4 { } {
# Discuss hydrophobicity in tail

    graphics [molinfo top] delete all

    set ::VMDlite::lesson::currentFrame 4
    eval ::VMDlite::lesson::refresh
    wm title ${::VMDlite::lesson::w} "VMDlite -- Phospholipids 4"

    # create cylinder around tails
    graphics [molinfo top] color 0
    graphics [molinfo top] material Transparent
    graphics [molinfo top] cylinder {-41 32 -8} {-41 32 18.2} radius 8 resolution 30 filled yes

    # add text for current frame
    set text \
"The two leg-like structures are known as the \"tails\". These are carbon chains, and are almost\
entirely nonpolar. Since water is polar, nonpolar molecules tend to avoid water whenever possible.\
We call this the \"hydrophobic effect\"."

	# add text for current frame
	eval [list ::VMDlite::lesson::textBox ${text}]

	::VMDlite::lesson::representationsButtons
}

# # # # # # # # # #
#
# MODULE SCREEN 5
#
# # # # # # # # # #

proc ::VMDlite::lesson::module5 { } {
# Discuss hydrophilicity in headgroup

    if {${::VMDlite::lesson::currentFrame}==6} {
        mol delete all   
        mol new ${::VMDlite::lesson::directory}/membrane/membrane.pdb
        mol addfile ${::VMDlite::lesson::directory}/membrane/membrane.psf

        mol addrep [molinfo top]
        mol addrep [molinfo top]
        mol modstyle 0 [molinfo top] Lines 2.0
        mol modstyle 1 [molinfo top] Licorice 0.5 30 30
        mol modstyle 2 [molinfo top] VDW 0.6 30
        mol showrep [molinfo top] 1 off
        mol showrep [molinfo top] 2 off

        mol modselect 0 [molinfo top] residue 458
        mol modselect 1 [molinfo top] residue 458
        mol modselect 2 [molinfo top] residue 458

        set sel [atomselect top "residue 458"]
        set center [measure center ${sel}]
        ${sel} delete
        molinfo top set center [list ${center}]
        scale by 4.0
        translate to 0 0 0
        display update

        rotate x by -90
        rotate y by 90
    }

    set ::VMDlite::lesson::currentFrame 5
    eval ::VMDlite::lesson::refresh
    wm title ${::VMDlite::lesson::w} "VMDlite -- Phospholipids 5"

    graphics [molinfo top] delete all
    graphics [molinfo top] material Transparent
    graphics [molinfo top] color 1
    graphics [molinfo top] cylinder {-41 32 18} {-41 32 25.5} radius 8 resolution 30 filled yes

    # add text for current frame
    set text \
"The top part is known as the \"headgroup\". It is typically composed of charged groups such\
as a phosphate (PO4(3-)). This asymmetry induces a polarity in the headgroup. We then call\
the headgroup \"hydrophilic\" (water loving)."


	# add text for current frame
	eval [list ::VMDlite::lesson::textBox ${text}]

	::VMDlite::lesson::representationsButtons
}

# # # # # # # # # #
#
# MODULE SCREEN 6
#
# # # # # # # # # #

proc ::VMDlite::lesson::module6 { } {
# Run double bilayer simulation

    mol delete all

    set ::VMDlite::lesson::currentFrame 6
    eval ::VMDlite::lesson::refresh
    wm title ${::VMDlite::lesson::w} "VMDlite -- Phospholipids 6"

    # add text for current frame
    set text \
"Here are lipids placed in water. Run the simulation by dragging the scale below\
and notice what happens.\n\nDon't forget you may switch representations as well\
to see the system differently. At the beginning of the simulation you can see that\
the system is just randomly oriented lipids in water. Press \"Play\" or drag the\
slider to watch the simulation. What do you notice?"

	# add text for current frame
	eval [list ::VMDlite::lesson::textBox ${text}]

    mol new ${::VMDlite::lesson::directory}/bilayers/bilayers.psf
    mol addfile ${::VMDlite::lesson::directory}/bilayers/bilayers.dcd waitfor all

    mol addrep [molinfo top]
    mol addrep [molinfo top]
    mol addrep [molinfo top]
    mol modstyle 0 [molinfo top] Lines 2.0
    mol modstyle 1 [molinfo top] Licorice 0.5 30 30
    mol modstyle 2 [molinfo top] VDW 1.7 30
    mol modstyle 3 [molinfo top] VDW 0.7

    mol modcolor 0 [molinfo top] Charge
    mol modcolor 1 [molinfo top] Charge
    mol modcolor 2 [molinfo top] Charge
    mol modcolor 3 [molinfo top] ColorID 10
    
    mol modselect 0 [molinfo top] "all and not water"
    mol modselect 1 [molinfo top] "all and not water"
    mol modselect 2 [molinfo top] "all and not water"
    mol modselect 3 [molinfo top] "water"
    mol showrep [molinfo top] 0 off
    mol showrep [molinfo top] 2 off
    
    rock y by 0
    rotate x by -90
    scale by 0.75
    animate goto 0
	
	# place representations buttons and DCD time scale
	::VMDlite::lesson::repButtonsAndDCD sliderPos

}

# # # # # # # # # #
#
# MODULE SCREEN 7
#
# # # # # # # # # #

proc ::VMDlite::lesson::module7 { } {
# Allow user to choose between five different simulations. Include time step
# scale bar and representations


    mol delete all

    set ::VMDlite::lesson::currentFrame 7
    eval ::VMDlite::lesson::refresh
    wm title ${::VMDlite::lesson::w} "VMDlite -- Phospholipids 7"

    # add text for current frame
    set text \
"Below are five different simulations to choose. Use the slide as before to progress\
through the simulations. Remember that you can click and drag anywhere in the window\
to rotate the view. Scrolling the mouse wheel will zoom in and out. Press \"Play\" to\
watch the simulation play out or drag the slider."

	# add text for current frame
	eval [list ::VMDlite::lesson::textBox ${text}]

    # radio with buttons for representations
    ttk::frame ${::VMDlite::lesson::w}.radio \
        -relief sunken
    ttk::label ${::VMDlite::lesson::w}.radio.label \
        -text "Representations"
    ttk::radiobutton ${::VMDlite::lesson::w}.radio.lines \
        -text "Lines" \
        -variable ::VMDlite::lesson::representation \
        -value "Lines" \
        -command ::VMDlite::lesson::showRep
    ttk::radiobutton ${::VMDlite::lesson::w}.radio.licorice \
        -text "Licorice" \
        -variable ::VMDlite::lesson::representation \
        -value "Licorice" \
        -command ::VMDlite::lesson::showRep
    ttk::radiobutton ${::VMDlite::lesson::w}.radio.vdw \
        -text "VDW" \
        -variable ::VMDlite::lesson::representation \
        -value "VDW" \
        -command ::VMDlite::lesson::showRep

   # radio but buttons for simulation
    ttk::frame ${::VMDlite::lesson::w}.radioSim \
        -relief sunken
    ttk::label ${::VMDlite::lesson::w}.simulations \
        -text "Simulation"
    ttk::radiobutton ${::VMDlite::lesson::w}.radioSim.micelleVacuum \
        -text "Lipids in vacuum" \
        -variable ::VMDlite::lesson::simulation \
        -value micelleVacuum \
        -command ::VMDlite::lesson::changeSimulation
    ttk::radiobutton ${::VMDlite::lesson::w}.radioSim.headgroupsVacuum \
        -text "Headgroups in vacuum" \
        -variable ::VMDlite::lesson::simulation \
        -value headgroupsVacuum \
        -command ::VMDlite::lesson::changeSimulation
    ttk::radiobutton ${::VMDlite::lesson::w}.radioSim.headgroupsWater \
        -text "Headgroups in water" \
        -variable ::VMDlite::lesson::simulation \
        -value headgroupsWater \
        -command ::VMDlite::lesson::changeSimulation
    ttk::radiobutton ${::VMDlite::lesson::w}.radioSim.tailsVacuum \
        -text "Tails in vacuum" \
        -variable ::VMDlite::lesson::simulation \
        -value tailsVacuum \
        -command ::VMDlite::lesson::changeSimulation
    ttk::radiobutton ${::VMDlite::lesson::w}.radioSim.tailsWater \
        -text "Tails in water" \
        -variable ::VMDlite::lesson::simulation \
        -value tailsWater \
        -command ::VMDlite::lesson::changeSimulation

    ttk::scale ${::VMDlite::lesson::w}.scale \
        -variable ::VMDlite::lesson::sliderPos

    # horizontal line for separation of scrollbar from buttons
    ttk::separator ${::VMDlite::lesson::w}.separator2 \
     	-orient horizontal

    # pack that shit in
    pack ${::VMDlite::lesson::w}.radio \
        -side top \
        -fill x \
        -expand true \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2

    pack ${::VMDlite::lesson::w}.radio.label \
        ${::VMDlite::lesson::w}.radio.lines \
        ${::VMDlite::lesson::w}.radio.licorice \
        ${::VMDlite::lesson::w}.radio.vdw \
	    -side left

    pack ${::VMDlite::lesson::w}.radioSim \
        -side top \
        -fill x \
        -expand true \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2

    pack ${::VMDlite::lesson::w}.radioSim.micelleVacuum \
        ${::VMDlite::lesson::w}.radioSim.headgroupsVacuum \
        ${::VMDlite::lesson::w}.radioSim.headgroupsWater \
        ${::VMDlite::lesson::w}.radioSim.tailsVacuum \
        ${::VMDlite::lesson::w}.radioSim.tailsWater \
	    -side left

    pack ${::VMDlite::lesson::w}.scale \
        -fill x \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2

    pack ${::VMDlite::lesson::w}.separator2 \
        -fill x \
        -pady 10 \
        -side bottom \
        -after ${::VMDlite::lesson::w}.radio
    
    # initialize selection buttons
    ${::VMDlite::lesson::w}.radioSim.micelleVacuum invoke
}


proc ::VMDlite::lesson::changeSimulation { } {
# This proc will allow the user to switch between the different simulations at the end.

    mol delete all
    mol new ${::VMDlite::lesson::directory}/${::VMDlite::lesson::simulation}/${::VMDlite::lesson::simulation}.psf
    mol addfile ${::VMDlite::lesson::directory}/${::VMDlite::lesson::simulation}/${::VMDlite::lesson::simulation}.dcd waitfor all
    
    if {${::VMDlite::lesson::simulation} == "headgroupsVacuum"} {
        scale by 5
    }

    mol addrep [molinfo top]
    mol addrep [molinfo top]
    mol addrep [molinfo top]
    mol modstyle 0 [molinfo top] Lines 2.0
    mol modstyle 1 [molinfo top] Licorice 0.5 30 30
    mol modstyle 2 [molinfo top] VDW 1.7 30
    mol modstyle 3 [molinfo top] VDW 0.6

    mol modcolor 0 [molinfo top] Charge
    mol modcolor 1 [molinfo top] Charge
    mol modcolor 2 [molinfo top] Charge
    mol modcolor 3 [molinfo top] ColorID 10
    
    mol modselect 0 [molinfo top] "all and not water"
    mol modselect 1 [molinfo top] "all and not water"
    mol modselect 2 [molinfo top] "all and not water"
    mol modselect 3 [molinfo top] "water"
    mol showrep [molinfo top] 0 off
    mol showrep [molinfo top] 2 off

    destroy ${::VMDlite::lesson::w}.scale
    
    # frame for time scale in DCD
    ttk::frame ${::VMDlite::lesson::w}.scale \
        -relief sunken
    
    switch ${::VMDlite::lesson::simulation} {
    
        micelleVacuum {
            set ::VMDlite::lesson::micelleVacuumTimeStep 0
            ttk::scale ${::VMDlite::lesson::w}.scale.bar \
                -from 0 -to 299 \
                -variable ::VMDlite::lesson::sliderPos \
                -command ::VMDlite::lesson::setTime
        }
        headgroupsVacuum {
            set ::VMDlite::lesson::headgroupsVacuumTimeStep 0
            ttk::scale ${::VMDlite::lesson::w}.scale.bar \
                -from 0 -to 249 \
                -variable ::VMDlite::lesson::sliderPos \
                -command ::VMDlite::lesson::setTime
            scale by 0.2
        }
        headgroupsWater {
            set ::VMDlite::lesson::headgroupsWaterTimeStep 0
            ttk::scale ${::VMDlite::lesson::w}.scale.bar \
                -from 0 -to 400 \
                -variable ::VMDlite::lesson::sliderPos \
                -command ::VMDlite::lesson::setTime
        }
        tailsVacuum {
            set ::VMDlite::lesson::tailsVacuumTimeStep 0
            ttk::scale ${::VMDlite::lesson::w}.scale.bar \
                -from 0 -to 100 \
                -variable ::VMDlite::lesson::sliderPos \
                -command ::VMDlite::lesson::setTime
        }
        tailsWater {
            set ::VMDlite::lesson::tailsWaterTimeStep 0
            ttk::scale ${::VMDlite::lesson::w}.scale.bar \
                -from 0 -to 299 \
                -variable ::VMDlite::lesson::sliderPos \
                -command ::VMDlite::lesson::setTime
        }
    }
    
    animate goto 0
    

    # buttons for manually moving through DCD
    ttk::button ${::VMDlite::lesson::w}.scale.play \
        -text "Play" \
        -command [list ::VMDlite::lesson::DCD 1]
    ttk::button ${::VMDlite::lesson::w}.scale.stop \
        -text "Stop" \
        -command [list ::VMDlite::lesson::DCD 0]
    ttk::button ${::VMDlite::lesson::w}.scale.stepBack \
        -text "Previous frame" \
        -command [list ::VMDlite::lesson::step prev]
    ttk::button ${::VMDlite::lesson::w}.scale.stepForward \
        -text "Next frame" \
        -command [list ::VMDlite::lesson::step next]
    
    pack ${::VMDlite::lesson::w}.scale \
        -before ${::VMDlite::lesson::w}.buttons \
        -fill x \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2
    pack ${::VMDlite::lesson::w}.scale.bar \
        -padx 2 -pady 2 \
        -ipadx 2 -ipady 2 \
        -fill x
    pack ${::VMDlite::lesson::w}.scale.stepBack \
        ${::VMDlite::lesson::w}.scale.play \
        ${::VMDlite::lesson::w}.scale.stop \
        ${::VMDlite::lesson::w}.scale.stepForward \
            -padx 2 -pady 2 \
            -ipadx 2 -ipady 2 \
            -side left    

    ${::VMDlite::lesson::w}.radio.licorice invoke
}
